module M {
    export class A__2 {
        name: string;
    }
    export function F2__2(x__3: number): string {
        return x__3.toString();
    }
}
module N {
    export class A__4 {
        id: number;
    }
    export function F2__4(x__5: number): string {
        return x__5.toString();
    }
}
